parosm
======
.. image:: https://api.codacy.com/project/badge/Grade/004cf7caae79449893432b604c0e3ad5    :target: https://www.codacy.com/app/matthias.gilch.mg/parosm?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=DaGuich/parosm&amp;utm_campaign=Badge_Grade

.. image:: https://api.codacy.com/project/badge/Coverage/004cf7caae79449893432b604c0e3ad5    :target: https://www.codacy.com/app/matthias.gilch.mg/parosm?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=DaGuich/parosm&amp;utm_campaign=Badge_Coverage
